@@ -251,16 +251,19 @@ class QuoteData(object):
 
         """
         year_minimum = 1990
+        start = datetime.datetime(2005,1,1).date()
         if period in ['day', 'daily', '1d']:
             trade_list = self.get_trade_days(end_date=date, count=count)
-            return trade_list[0].timetuple()
+            if trade_list:
+                start = trade_list[0].timetuple()
         elif period in ['week', '1w']:
             trade_list = self.get_trade_days(end_date=date, count=count * 5)
-            week_maps = [x.isocalendar()[0] * 100 + x.isocalendar()[1] for x in trade_list]
-            week_list = list(set(week_maps))
-            week_list.sort()
-            w = week_list[-count]
-            return trade_list[week_maps.index(w)].timetuple()
+            if trade_list:
+                week_maps = [x.isocalendar()[0] * 100 + x.isocalendar()[1] for x in trade_list]
+                week_list = list(set(week_maps))
+                week_list.sort()
+                w = week_list[-count]
+                start = trade_list[week_maps.index(w)].timetuple()
         elif period in ['mon', 'month', '1M']:
             y = date.tm_year
             m = date.tm_mon + 1 - count
@@ -287,7 +290,8 @@ class QuoteData(object):
                 return
             days = math.ceil(count * n / 240)
             trade_list = self.get_trade_days(end_date=date, count=days)
-            start = trade_list[0].timetuple()
+            if trade_list:
+                start = trade_list[0].timetuple()
         return start
 
     def trace(self, *args):
